----------------------------------------------------------------------------
-- xplordb
-- 
-- Copyright (C) 2022  Oslandia / OpenLog
-- This program is free software: you can redistribute it and/or modify
-- it under the terms of the GNU Affero General Public License as published
-- by the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU Affero General Public License for more details.
-- 
-- You should have received a copy of the GNU Affero General Public License
-- along with this program.  If not, see <https://www.gnu.org/licenses/>.
-- 
-- __authors__ = ["davidms"]
-- __contact__ = "geology@oslandia.com"
-- __date__ = "2022/02/02"
-- __license__ = "AGPLv3"
----------------------------------------------------------------------------

--
-- PostgreSQL database dump
--

-- Dumped from database version 13.5 (Ubuntu 13.5-0ubuntu0.21.10.1)
-- Dumped by pg_dump version 13.5 (Ubuntu 13.5-0ubuntu0.21.10.1)

SET statement_timeout = 0;
SET lock_timeout = 0;
SET idle_in_transaction_session_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = on;
SELECT pg_catalog.set_config('search_path', '', false);
SET check_function_bodies = false;
SET xmloption = content;
SET client_min_messages = warning;
SET row_security = off;

--
-- Data for Name: units; Type: TABLE DATA; Schema: ref; Owner: postgres
--

COPY ref.units (code, description, loaded_by, load_date) FROM stdin;
ppm	parts per million	fp	2009-05-27 18:00:00+02
ppt	parts per trillion	fp	2009-05-27 18:00:00+02
pct	percentage	fp	2009-05-27 18:00:00+02
gt	grams per tonne	fp	2009-05-27 18:00:00+02
ozt	troy ounces per tonne	fp	2009-05-27 18:00:00+02
%	percentage	fp	2009-05-27 18:00:00+02
ppb	parts per billion	fp	2009-05-27 18:00:00+02
kg	kilograms	fp	2013-03-07 17:00:00+01
g	grams	fp	2020-03-05 15:18:11.258347+01
NA	not applicable	fp	2020-03-05 15:21:20.418036+01
cm	centimeters	fp	2020-04-03 09:38:07.063545+02
mm	millimeteres	fp	2020-04-03 09:39:00.095585+02
inches	inches	fp	2020-04-03 09:39:48.615162+02
m	meters	fp	2020-04-03 09:40:27.903053+02
\.


--
-- PostgreSQL database dump complete
--

